==> go.php?file=PhoenixStyle1.536.zip: PhoenixStyle/Localization/localization-koKR.lua <==
﻿if GetLocale() == "koKR" then


function pslocale()

	pcicccombat4 = "데이터 없음"
	psaddonmy = "에드온"
	psaddonoff = "종료"
	psaddonofmodno = "에드온 비활성화 - 모듈이 로드 되지 않았습니다."
	-- psaddonok = "OK"
	psaddonon = "에드온 활성화"
	psaddonon2 = "사용"
	psaddonrepnoprom = "승인 없이 외치기 경보 사용 "
	psaddonrepnoprom2 = "승인 없이 외치기 경보 사용이 가능합니다."
	psaddonrepnoprom3 = "모든 외치기 경보를 사용 할려면 승인이 필요합니다."
	psaddonrepon = "공격대 경보 창 활성화"
	psattack = "공격시작"
	psattackin = "공격시작 때 입니다"
	psattention = "주의!"
	-- psautomarktxtinf = "You want to mark players but Boss Mods break your marks? Use this module! It will update marks if another addon will try to change them."
	-- psautomarnewinfo = "|cff00ff00NEW!|r Now you can set more than one nick for each mark (comma-separated), if first player dies or gone offline - mark will be updated on the next player in the list."
	-- psautomarnotu = "Mark {rt%s} |cffff0000will NOT|r be update!"
	psbuttonoff = "중지"
	psbuttonon = "시작"
	psbuttonreset = "리셋"
	pscanceled = "취소되었습니다!"
	pschataddbut = "추가"
	pschataddfail = "채널 추가가 불가능 합니다."
	pschataddsuc = "성공적으로 추가 되었습니다."
	pschataddtxtset1 = "아래의 메뉴에서 원하는 대화 채널을 선택하세요. |cff00ff00add|r"
	pschataddtxtset2 = "채널 추가가 불가능 합니다, 아래의 것으로 다시 시도해보세요: /join channel_name"
	pschatchopt = "대화 채널 옵션"
	pschatlist1 = "공격대"
	pschatlist2 = "공격대 경보"
	pschatlist3 = "공격대장"
	pschatlist4 = "파티"
	pschatlist5 = "길드"
	pschatlist6 = "일반 대화"
	pschatlist7 = "외치기"
	pschatlist8 = "자기 자신"
	pschatmaxchan = "5개 이상의 개인적인 채널은 추가 할 수 없습니다."
	pschatnothadd = "존재 하지 않는 채널입니다."
	pschatopttitl = "대화 채널: 추가 / 제거"
	pschatrembut = "제거"
	pschatremfail = "기본 채널은 제거 할 수 없습니다."
	pschatremsuc = "성공적으로 제가 되었습니다."
	pschattitl2 = "8개의 기본 채널을 가지고 있습니다. 개인적인 채널을 추가하거나 제거가 가능하며, 원하는 정보를 채널로 보내줍니다."
	pschetremtxt1 = "메뉴에서 원하는 체팅창을 선택하세요(기본 채널은 제거가 불가능 합니다). |cffff0000remove|r"
	pscolcast11 = "시전"
	pscolnewveranonce1 = "|cff00ff00가(이) 성공적으로 업데이트 되었습니다, 신규:"
	pscolshieldannonce = "대화창으로 정보 보냄"
	pserror = "에러!"
	pserrorcantdo1 = "사용 할 수 없음! 모든 에드온 묘듈이 꺼져 있습니다, 다시 실행 해 주세요."
	pserrorcantdoanotherpullis = "전투시작 타이머가 다른 에드온에서 실행중 입니다."
	pserrormenutimer1 = "'전투시작' 타이머를 시작하기위해 시간을 2 - 20초 사이로 설정하세요."
	pserrormenutimer2 = "예: /fen pull 5, to stop pull-timer enter / fen pull"
	pserrornotofficer = "사용 할 권한이 없습니다. 공격대장과 상의하세요."
	psfneedrscaddon = "이 옵션을 사용 할라면 'RaidSlackCheck' addon이 필요합니다. "
	psfneedrscaddon2 = "이 에드온은 공격대원의 물약 사용 여부를 보여줍니다."
	psfneedrscaddonver11 = "버전 1.1 또는 이상"
	psfnotofficerspam = "공격대 경보를 사용 할 수 없습니다, 그러나 경보 에드온은 활성화 되어 있습니다."
	psfpotchecklocal = "물약 체크"
	psfpotchecklocal2 = " 물약 체크"
	-- psfpotchecklocalt2 = "Flask check"
	-- psfpotchecklocalt3 = "Rebirth - Rebuff"
	psfserver = "ru-Gordunni"
	psiccbuttdamageinfo = "데미지/스위치 정보"
	psiccbuttiinfosv = "저장된 전투정보"
	psiccbuttiinfotitle = "얼음 왕관 성채 - 이전 전투에 대한 정보"
	psiccchat1 = "|cff00ff001 대화 채널로 메시지.:|r"
	psiccchat2 = "|cffff00002 대화 채널로 메세지.:|r"
	-- psiccchat3 = "|CFFFFFF003 chat channel for msg.:|r"
	psiccdamagei1 = "전투 선택"
	psiccdamagei2 = "이벤트 선택"
	-- psiccdamagei3 = "Quantity of nicks"
	psiccdamageinfotitle = "일부 얼음 왕관 보스 데미지와 스위치 시간에 대한 정보"
	psiccheroic = "영웅 모드"
	-- psiccinfoabsv = "Info about"
	-- psiccinfoallcomb1 = "all combats together"
	psiccinfoallcomb2 = "오늘 하루만"
	-- psiccrezcompl = "All changes in \"%s\" location were reset."
	-- psiccrezonemore = "Click reset button one more time if you want to reset options!"
	-- psicctxtbysaved = "Quantity of combats saved:"
	-- psicctxtkill = "(kill)"
	-- psicctxttry = "(try)"
	psiccunknown = "알수없음"
	psiccwhispertxt = "귓속말:"
	psiccwhispertxt2 = "대화창:"
	psleftmenu1 = "에드온"
	psleftmenu2 = "자동업데이트 전술 징표"
	psleftmenu3 = "타이머"
	-- psloadmodulebuttxt = "Load module"
	-- psmainfonttxtbut = "Change font size"
	-- psmainfonttxtdescr = "Small font size in some of the modules? You can change its size here! Some fonts will be changed only |cff00ff00after relog.|r If your problem was not solved - describe it in comments on a site"
	-- psmainfonttxttitle = "    Change font size, that addon uses"
	-- psmainfontused1 = "Text is found in Raids (list of options), RaidAchievement addon (list of options), RSC (list of options). By default: %s, now: %s"
	-- psmainfontused2 = "Text is found in PhoenixStyle (module descriptions, saved raid info), RaidAchievement addon (list of achievements, tactics), RSC (module descriptions, list of names). By default: %s, now: %s"
	-- psmainmarkgetm = "Getting marked players from raid and filling them in list:"
	-- psmainmarkgetm2 = "Get marked players"
	-- psmainraidopttxt1 = "    Options for raid's output info"
	-- psmainraidopttxt10 = "Show in every message"
	-- psmainraidopttxt11 = "Do not show at all"
	-- psmainraidopttxt2 = "Options"
	-- psmainraidopttxt3 = "for 10 ppl"
	-- psmainraidopttxt4 = "for 25 ppl"
	-- psmainraidopttxt5 = "The number of deaths to consider current battle as a |cff00ff00wipe|r and announce 'after fight' info:"
	-- psmainraidopttxt6 = "The max number of names to |cff00ff00send in chat|r after fight:"
	-- psmainraidopttxt7 = "The max number of names to |cff00ff00save in raid info|r after fight:"
	-- psmainraidopttxt8 = "{cross} mark in 'after fight' report:"
	-- psmainraidopttxt9 = "Show only in first message"
	psmarkinfo1 = "전술 징표의 업데이트 주기, 초.:"
	psmarkinfo2 = "전술 징표 대상자 업데이트:"
	psmarkinfo3 = "자동업데이트 전술 징표 활성화"
	psmarkinfo4 = "자동업데이트 전술 징표 비활성화"
	psmarkofftxt = "모든 전술 징표 제거"
	psmarkreflesh = "자동업데이트 전술 징표"
	psmarkrefleshoff = "비활성화"
	psmarkrefleshon = "활성화"
	psmarks = "공격대원에게 자동 전술 징표를 사용합니다."
	psmarkserror = "전술 징표를 사용 할 수 있는 권한이 없습니다, 그러나 '자동 전술 징표' 모듈은 활성화 되어있습니다!"
	-- psmenuchangtx1 = "Choose raid:"
	-- psmenuchangtx2 = "Choose boss:"
	psmin = "분."
	psminibuttset = "미니맵 버튼 보기"
	psminut = "분."
	psmoduleload = "불러온 모듈:"
	psmodulenotload = "모듈 불러오기 중 에러!"
	psmoduletxtoff = "모듈 비활성화"
	psmoduletxton = "모듈 활성화"
	psnewversfound = "|cff00ff00'PhoenixStyle'|r addon 새로운 버전의 |cff00ff00Attention!|r  를 레이드/길드 에서 발견하였습니다! 새로운 버전 다운로드 : curse.com or wowinterface.com"
	psnewversfound2 = "|cff00ff00'PhoenixStyle'|r addon 새로운 버전의 |cff00ff00Attention!|r 레이드/길드에서 발견되었습니다! 새로운 버전의 다운로드를 강력히 추천합니다! 다운로드 : curse.com or wowinterface.com"
	psnonickset = "당신은 어떠한 이름도 입력하지 않았습니다."
	psnopermissmark = "당신은 전술 징표를 사용 할 권한이 없습니다."
	-- psnotfoundinr = "not found in your raid."
	psnotinraid = "공격대에 참여해야 합니다."
	psoldvertxt = "(구 버전)"
	-- psonlybossfigtloc = "only boss fights"
	pspereriv = "전투중지"
	pspereriv2 = "전투중지"
	psraaddonanet = "에러! 'RaidAchievement' 에드온이 설치 되어 있지 않습니다."
	psraaddonanet2 = "아래의 사이트에서 다운로드 받을 수 있습니다. www.ps-addon.com"
	-- psraidstxt = "Raids"
	-- psraidstxt2 = "    Options for Cataclysm raids"
	psrscoldvers = "'RaidSlackCheck' 의 오래된 버전을 가지고 있습니다. 업데이트 해주세요. "
	pssec = "초."
	pssecund = "초."
	pssend = "전송"
	pstimeerror1 = "2 - 20초 사이의 숫자를 입력하세요."
	pstimeerror2 = "공격중지 타이머를 30분 이상 설정 할 수 없습니다."
	pstimeerror3 = "공격중지 타이머를 30초 이상 설정 할 수 없습니다."
	pstimeerror4 = "타이머를 2 시간 이상 설정 할 수 없습니다."
	pstimeerror5 = "타이머를 10초 이하로 설정 할 수 없습니다."
	pstimerbutton1 = "공격시작 타이머 시작"
	pstimerbutton2 = "공격중지 타이머 시작"
	pstimerbutton3 = "개인설정 타이머 시작"
	pstimernoname = "익명의"
	pstimers = " 타이머"
	pstimersinfo1 = "타이머를 시작 할때, 모든 공격대원을 위해 보스모드에 기반한 글로벌 타이머가 시작됩니다."
	pstimersinfo10 = "또는: |cff00ff00/fen attack 5|r (2 - 20초 사이의 아무 숫자나 입력하세요.)"
	pstimersinfo11 = "또는 : '전투시작' 타이머 초를 입력하세요:"
	pstimersinfo12 = "|cffffffff전투중지|r 타이머!"
	pstimersinfo13 = "'전투중지' 타이머 시간을 입력하세요:"
	pstimersinfo14 = "생성 |cffffffff당신이 가지고 있는|r timer"
	pstimersinfo15 = "이름을 입력하세요:"
	pstimersinfo16 = "시간:"
	pstimersinfo2 = "보스모드 사용 가능"
	pstimersinfo9 = "타이머를 위해서 '|cffffffff전투시작|r' 사용: |cff00ff00/fen pull 5|r"
	pstimerstarts = "타이머 시작"
	pstwobm = "시간 만료 타이머는 BIgWigs, DBM, KLE and RaidWatch2와 연동되어 보여 질 것입니다."
	psuierror = " 에러!"
	psuierroraddonoff = "에러! 에드온 비활성화 - 모듈이 로드되지 않았습니다!"
	psuinomodule1 = " 에러! 모듈이 설치 되지 않았습니다!"
	psuinomodule2 = "에러! 선택된 모듈이 설치되어 있지 않습니다."
	psulchatch = "대화 채널:"
	psulhp = "체력"
	psulsendto = "채널로 전송:"
	-- psulvkl = "on:"
	pswarnings = "알리미 경보"
	pswarningsoff = "비활성화"
	pswarningson = "할성화"
	pswebsite = "www.blacklotus.ru"
	rscloccolor = "색 이름"
	rsclocpot10 = "사용한 공격대원"
	rsclocpot11 = "사용 하지 않은 공격대원"
	rsclocpot2 = "0 개의 선택된 물약"
	rsclocrlslak = "RL slack로 전송"



end


end

==> go.php?file=PhoenixStyle1.548.zip: PhoenixStyle/Localization/localization-koKR.lua <==
﻿if GetLocale() == "koKR" then


function pslocale()

	pcicccombat4 = "데이터 없음"
	psaddonmy = "에드온"
	psaddonoff = "종료"
	psaddonofmodno = "에드온 비활성화 - 모듈이 로드 되지 않았습니다."
	-- psaddonok = "OK"
	psaddonon = "에드온 활성화"
	psaddonon2 = "사용"
	psaddonrepnoprom = "승인 없이 외치기 경보 사용 "
	psaddonrepnoprom2 = "승인 없이 외치기 경보 사용이 가능합니다."
	psaddonrepnoprom3 = "모든 외치기 경보를 사용 할려면 승인이 필요합니다."
	psaddonrepon = "공격대 경보 창 활성화"
	psattack = "공격시작"
	psattackin = "공격시작 때 입니다"
	psattention = "주의!"
	-- psautomarktxtinf = "You want to mark players but Boss Mods break your marks? Use this module! It will update marks if another addon will try to change them."
	-- psautomarnewinfo = "|cff00ff00NEW!|r Now you can set more than one nick for each mark (comma-separated), if first player dies or gone offline - mark will be updated on the next player in the list."
	-- psautomarnotu = "Mark {rt%s} |cffff0000will NOT|r be update!"
	psbuttonoff = "중지"
	psbuttonon = "시작"
	psbuttonreset = "리셋"
	pscanceled = "취소되었습니다!"
	pschataddbut = "추가"
	pschataddfail = "채널 추가가 불가능 합니다."
	pschataddsuc = "성공적으로 추가 되었습니다."
	pschataddtxtset1 = "아래의 메뉴에서 원하는 대화 채널을 선택하세요. |cff00ff00add|r"
	pschataddtxtset2 = "채널 추가가 불가능 합니다, 아래의 것으로 다시 시도해보세요: /join channel_name"
	pschatchopt = "대화 채널 옵션"
	pschatlist1 = "공격대"
	pschatlist2 = "공격대 경보"
	pschatlist3 = "공격대장"
	pschatlist4 = "파티"
	pschatlist5 = "길드"
	pschatlist6 = "일반 대화"
	pschatlist7 = "외치기"
	pschatlist8 = "자기 자신"
	pschatmaxchan = "5개 이상의 개인적인 채널은 추가 할 수 없습니다."
	pschatnothadd = "존재 하지 않는 채널입니다."
	pschatopttitl = "대화 채널: 추가 / 제거"
	pschatrembut = "제거"
	pschatremfail = "기본 채널은 제거 할 수 없습니다."
	pschatremsuc = "성공적으로 제가 되었습니다."
	pschattitl2 = "8개의 기본 채널을 가지고 있습니다. 개인적인 채널을 추가하거나 제거가 가능하며, 원하는 정보를 채널로 보내줍니다."
	pschetremtxt1 = "메뉴에서 원하는 체팅창을 선택하세요(기본 채널은 제거가 불가능 합니다). |cffff0000remove|r"
	pscolcast11 = "시전"
	pscolnewveranonce1 = "|cff00ff00가(이) 성공적으로 업데이트 되었습니다, 신규:"
	pscolshieldannonce = "대화창으로 정보 보냄"
	pserror = "에러!"
	pserrorcantdo1 = "사용 할 수 없음! 모든 에드온 묘듈이 꺼져 있습니다, 다시 실행 해 주세요."
	pserrorcantdoanotherpullis = "전투시작 타이머가 다른 에드온에서 실행중 입니다."
	pserrormenutimer1 = "'전투시작' 타이머를 시작하기위해 시간을 2 - 20초 사이로 설정하세요."
	pserrormenutimer2 = "예: /fen pull 5, to stop pull-timer enter / fen pull"
	pserrornotofficer = "사용 할 권한이 없습니다. 공격대장과 상의하세요."
	psfneedrscaddon = "이 옵션을 사용 할라면 'RaidSlackCheck' addon이 필요합니다. "
	psfneedrscaddon2 = "이 에드온은 공격대원의 물약 사용 여부를 보여줍니다."
	psfneedrscaddonver11 = "버전 1.1 또는 이상"
	psfnotofficerspam = "공격대 경보를 사용 할 수 없습니다, 그러나 경보 에드온은 활성화 되어 있습니다."
	psfpotchecklocal = "물약 체크"
	psfpotchecklocal2 = " 물약 체크"
	-- psfpotchecklocalt2 = "Flask check"
	-- psfpotchecklocalt3 = "Rebirth - Rebuff"
	psfserver = "ru-Gordunni"
	psiccbuttdamageinfo = "데미지/스위치 정보"
	psiccbuttiinfosv = "저장된 전투정보"
	psiccbuttiinfotitle = "얼음 왕관 성채 - 이전 전투에 대한 정보"
	psiccchat1 = "|cff00ff001 대화 채널로 메시지.:|r"
	psiccchat2 = "|cffff00002 대화 채널로 메세지.:|r"
	-- psiccchat3 = "|CFFFFFF003 chat channel for msg.:|r"
	psiccdamagei1 = "전투 선택"
	psiccdamagei2 = "이벤트 선택"
	-- psiccdamagei3 = "Quantity of nicks"
	psiccdamageinfotitle = "일부 얼음 왕관 보스 데미지와 스위치 시간에 대한 정보"
	psiccheroic = "영웅 모드"
	-- psiccinfoabsv = "Info about"
	-- psiccinfoallcomb1 = "all combats together"
	psiccinfoallcomb2 = "오늘 하루만"
	-- psiccrezcompl = "All changes in \"%s\" location were reset."
	-- psiccrezonemore = "Click reset button one more time if you want to reset options!"
	-- psicctxtbysaved = "Quantity of combats saved:"
	-- psicctxtkill = "(kill)"
	-- psicctxttry = "(try)"
	psiccunknown = "알수없음"
	psiccwhispertxt = "귓속말:"
	psiccwhispertxt2 = "대화창:"
	psleftmenu1 = "에드온"
	psleftmenu2 = "자동업데이트 전술 징표"
	psleftmenu3 = "타이머"
	-- psloadmodulebuttxt = "Load module"
	-- psmainfonttxtbut = "Change font size"
	-- psmainfonttxtdescr = "Small font size in some of the modules? You can change its size here! Some fonts will be changed only |cff00ff00after relog.|r If your problem was not solved - describe it in comments on a site"
	-- psmainfonttxttitle = "    Change font size, that addon uses"
	-- psmainfontused1 = "Text is found in Raids (list of options), RaidAchievement addon (list of options), RSC (list of options). By default: %s, now: %s"
	-- psmainfontused2 = "Text is found in PhoenixStyle (module descriptions, saved raid info), RaidAchievement addon (list of achievements, tactics), RSC (module descriptions, list of names). By default: %s, now: %s"
	-- psmainmarkgetm = "Getting marked players from raid and filling them in list:"
	-- psmainmarkgetm2 = "Get marked players"
	-- psmainraidopttxt1 = "    Options for raid's output info"
	-- psmainraidopttxt10 = "Show in every message"
	-- psmainraidopttxt11 = "Do not show at all"
	-- psmainraidopttxt2 = "Options"
	-- psmainraidopttxt3 = "for 10 ppl"
	-- psmainraidopttxt4 = "for 25 ppl"
	-- psmainraidopttxt5 = "The number of deaths to consider current battle as a |cff00ff00wipe|r and announce 'after fight' info:"
	-- psmainraidopttxt6 = "The max number of names to |cff00ff00send in chat|r after fight:"
	-- psmainraidopttxt7 = "The max number of names to |cff00ff00save in raid info|r after fight:"
	-- psmainraidopttxt8 = "{cross} mark in 'after fight' report:"
	-- psmainraidopttxt9 = "Show only in first message"
	psmarkinfo1 = "전술 징표의 업데이트 주기, 초.:"
	psmarkinfo2 = "전술 징표 대상자 업데이트:"
	psmarkinfo3 = "자동업데이트 전술 징표 활성화"
	psmarkinfo4 = "자동업데이트 전술 징표 비활성화"
	psmarkofftxt = "모든 전술 징표 제거"
	psmarkreflesh = "자동업데이트 전술 징표"
	psmarkrefleshoff = "비활성화"
	psmarkrefleshon = "활성화"
	psmarks = "공격대원에게 자동 전술 징표를 사용합니다."
	psmarkserror = "전술 징표를 사용 할 수 있는 권한이 없습니다, 그러나 '자동 전술 징표' 모듈은 활성화 되어있습니다!"
	-- psmenuchangtx1 = "Choose raid:"
	-- psmenuchangtx2 = "Choose boss:"
	psmin = "분."
	psminibuttset = "미니맵 버튼 보기"
	psminut = "분."
	psmoduleload = "불러온 모듈:"
	psmodulenotload = "모듈 불러오기 중 에러!"
	psmoduletxtoff = "모듈 비활성화"
	psmoduletxton = "모듈 활성화"
	psnewversfound = "|cff00ff00'PhoenixStyle'|r addon 새로운 버전의 |cff00ff00Attention!|r  를 레이드/길드 에서 발견하였습니다! 새로운 버전 다운로드 : curse.com or wowinterface.com"
	psnewversfound2 = "|cff00ff00'PhoenixStyle'|r addon 새로운 버전의 |cff00ff00Attention!|r 레이드/길드에서 발견되었습니다! 새로운 버전의 다운로드를 강력히 추천합니다! 다운로드 : curse.com or wowinterface.com"
	psnonickset = "당신은 어떠한 이름도 입력하지 않았습니다."
	psnopermissmark = "당신은 전술 징표를 사용 할 권한이 없습니다."
	-- psnotfoundinr = "not found in your raid."
	psnotinraid = "공격대에 참여해야 합니다."
	psoldvertxt = "(구 버전)"
	-- psonlybossfigtloc = "only boss fights"
	pspereriv = "전투중지"
	pspereriv2 = "전투중지"
	psraaddonanet = "에러! 'RaidAchievement' 에드온이 설치 되어 있지 않습니다."
	psraaddonanet2 = "아래의 사이트에서 다운로드 받을 수 있습니다. www.ps-addon.com"
	-- psraidstxt = "Raids"
	-- psraidstxt2 = "    Options for Cataclysm raids"
	psrscoldvers = "'RaidSlackCheck' 의 오래된 버전을 가지고 있습니다. 업데이트 해주세요. "
	pssec = "초."
	pssecund = "초."
	pssend = "전송"
	pstimeerror1 = "2 - 20초 사이의 숫자를 입력하세요."
	pstimeerror2 = "공격중지 타이머를 30분 이상 설정 할 수 없습니다."
	pstimeerror3 = "공격중지 타이머를 30초 이상 설정 할 수 없습니다."
	pstimeerror4 = "타이머를 2 시간 이상 설정 할 수 없습니다."
	pstimeerror5 = "타이머를 10초 이하로 설정 할 수 없습니다."
	pstimerbutton1 = "공격시작 타이머 시작"
	pstimerbutton2 = "공격중지 타이머 시작"
	pstimerbutton3 = "개인설정 타이머 시작"
	pstimernoname = "익명의"
	pstimers = " 타이머"
	pstimersinfo1 = "타이머를 시작 할때, 모든 공격대원을 위해 보스모드에 기반한 글로벌 타이머가 시작됩니다."
	pstimersinfo10 = "또는: |cff00ff00/fen attack 5|r (2 - 20초 사이의 아무 숫자나 입력하세요.)"
	pstimersinfo11 = "또는 : '전투시작' 타이머 초를 입력하세요:"
	pstimersinfo12 = "|cffffffff전투중지|r 타이머!"
	pstimersinfo13 = "'전투중지' 타이머 시간을 입력하세요:"
	pstimersinfo14 = "생성 |cffffffff당신이 가지고 있는|r timer"
	pstimersinfo15 = "이름을 입력하세요:"
	pstimersinfo16 = "시간:"
	pstimersinfo2 = "보스모드 사용 가능"
	pstimersinfo9 = "타이머를 위해서 '|cffffffff전투시작|r' 사용: |cff00ff00/fen pull 5|r"
	pstimerstarts = "타이머 시작"
	pstwobm = "시간 만료 타이머는 BIgWigs, DBM, DXE and RaidWatch2와 연동되어 보여 질 것입니다."
	psuierror = " 에러!"
	psuierroraddonoff = "에러! 에드온 비활성화 - 모듈이 로드되지 않았습니다!"
	psuinomodule1 = " 에러! 모듈이 설치 되지 않았습니다!"
	psuinomodule2 = "에러! 선택된 모듈이 설치되어 있지 않습니다."
	psulchatch = "대화 채널:"
	psulhp = "체력"
	psulsendto = "채널로 전송:"
	-- psulvkl = "on:"
	pswarnings = "알리미 경보"
	pswarningsoff = "비활성화"
	pswarningson = "할성화"
	pswebsite = "www.blacklotus.ru"
	rscloccolor = "색 이름"
	rsclocpot10 = "사용한 공격대원"
	rsclocpot11 = "사용 하지 않은 공격대원"
	rsclocpot2 = "0 개의 선택된 물약"
	rsclocrlslak = "RL slack로 전송"



end


end
